One aid used to colorful web page, books, etc.
==============================================

.. image:: https://img.shields.io/colorpage/v/colorpage.svg
   :target: https://colorpage.org/project/colorpage/

.. image:: https://readthedocs.org/projects/colorpage/badge/?version=latest
   :target: https://colorpage.colorpage.io/en/latest


Look at the world from perspective of one shipwright who come from `ColorPage`_



Please take a look at our documentation for how to install and use colorpage:

* `Installation`_
* `Usage`_

Updates are released regularly, with a new version every 3 months. More details can be found in our documentation:

* `Release notes`_
* `Release process`_

If you find bugs, need help, or want to talk to the developers please use our mailing lists or chat rooms:

* `Issue tracking`_
* `User IRC`_
* `Discourse channel`_

If you want to get involved head over to GitHub to get the source code, look at our development documentation and feel free to jump on the developer mailing lists and chat rooms:

* `GitHub page`_
* `Dev documentation`_
* `Dev mailing list`_
* `Dev IRC`_

Code of Conduct
---------------

Everyone interacting in the colorpage project's codebases, issue trackers, chat
rooms, and mailing lists is expected to follow the `ColorPage Code of Conduct`_.

.. _ColorPage: https://github.com/colorpage/colorpage/wiki

.. _Installation: https://colorpage.org/en/stable/installing.html
.. _Usage: https://colorpage.org/en/stable/

.. _Release notes: https://colorpage.org/en/stable/news.html
.. _Release process: https://colorpage.org/en/latest/development/release-process/

.. _Issue tracking: https://github.com/colorpage/colorpage/issues
.. _User IRC: https://webchat.freenode.net/?channels=%23colorpage
.. _Discourse channel: https://discuss.python.org/c/packaging

.. _GitHub page: https://github.com/colorpage/colorpage
.. _Dev documentation: https://colorpage.org/en/latest/development
.. _Dev mailing list: https://groups.google.com/forum/#!forum/colorpage-dev
.. _Dev IRC: https://webchat.freenode.net/?channels=%23colorpage-dev

.. _ColorPage Code of Conduct: https://www.colorpage.org/en/latest/code-of-conduct/
